@@ -1,12 +1,12 @@
 package LinkLocal::IPv4::Interface;
 
-use 5.010000;
+require 5.010000;
 
-require Exporter;
-our @ISA         = qw(Exporter);
-our %EXPORT_TAGS = ();
-our @EXPORT_OK   = ();
-our @EXPORT      = qw();
+# require Exporter;
+# our @ISA         = qw(Exporter);
+# our %EXPORT_TAGS = ();
+# our @EXPORT_OK   = ();
+# our @EXPORT      = qw();
 
 # Copyright © 2010 Raymond Mroz
 #
@@ -31,17 +31,7 @@ our @EXPORT      = qw();
 
 use Moose;
 use Moose::Util::TypeConstraints;
-use IO::Interface::Simple;
-use Regexp::Common qw/ net /;
-
-use LinkLocal::IPv4::Interface::Constants;
-
-subtype 'LinkLocalInterface' 
-	=> as class_type('IO::Interface::Simple');
-
-coerce 'LinkLocalInterface' 
-	=> from 'Str' 
-	=> via { IO::Interface::Simple->new($_) };
+use LinkLocal::IPv4::Interface::Types;
 
 # =============
 # = interface =
@@ -60,11 +50,6 @@ has 'interface' => (
     coerce => 1,
 );
 
-subtype 'IpAddress' 
-	=> as 'Str' 
-	=> where { /^$RE{net}{IPv4}/ } 
-	=> message { "$_: Invalid IPv4 address format." };
-
 # ================
 # = address_list =
 # ================
@@ -136,7 +121,7 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 NAME
 
-LinkLocal::IPv4::Interface - IPv4 Link-Local network interface wrapper
+LinkLocal::IPv4::Interface - Moose-based network interface object wrapper
 
 =head1 SYNOPSIS
 
@@ -152,11 +137,7 @@ unmanaged IP networks. Based upon IETF standard RFC 3927, LinkLocal::IPv4::Inter
 provides a simple and lightweight framework for dynamic configuration of network 
 interfaces with IPv4 Link-Local addresses. 
 
-TODO Add additional/proper POD
-
-NOTE This is thread bare and still rather useless I am afraid. I am currently de-crufting
-a couple of additional modules which provide further function and those will be added
-very soon.
+# TODO Add additional/proper POD
 
 =head2 ATTRIBUTES
 
