@@ -2,6 +2,21 @@ package LinkLocal::IPv4::Interface::Constants;
 
 our $VERSION = '0.10';
 
+# Copyright © 2010 Raymond Mroz
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 use constant {
 	# RFC 3927 defined constants
     PROBE_WAIT          => 1,
@@ -48,6 +63,6 @@ our @EXPORT    = qw (
   DEFEND_INTERVAL
 );
 
-"Farmer Tedd was here";
+"PacMan was here";
 __END__
 
